riemannx v2.0.0 Riemannx View Source
Riemannx is a riemann client that supports UDP/TCP sockets and also supports a hybrid connection where smaller packets are sent via UDP and the rest over TCP.
For configuration instructions look at the individual connection modules.